==> jc-1.4.0.tar.gz: soot/grimp/internal/GLeExpr.h <==
// public class soot.grimp.internal.GLeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cf732f32c840ec26 soot_grimp_internal_AbstractGrimpIntBinopExpr
// @dep_class 864d3a598d926ee0 soot_grimp_internal_GLeExpr
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class f9eab9f2510f54c9 soot_jimple_internal_AbstractIntBinopExpr

// header file dependencies
// @dep_header soot_grimp_internal_AbstractGrimpIntBinopExpr

#include "soot/grimp/internal/AbstractGrimpIntBinopExpr.h"

#ifndef _JC_soot_grimp_internal_GLeExpr_H_
#define _JC_soot_grimp_internal_GLeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GLeExpr$sub_refs	_jc_soot_grimp_internal_GLeExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GLeExpr$sub_nonrefs	_jc_soot_grimp_internal_GLeExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GLeExpr$refs	_jc_soot_grimp_internal_GLeExpr$refs;
typedef struct _jc_soot_grimp_internal_GLeExpr$nonrefs	_jc_soot_grimp_internal_GLeExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GLeExpr$object	_jc_soot_grimp_internal_GLeExpr$object;

typedef const struct _jc_soot_grimp_internal_GLeExpr$vmethods	_jc_soot_grimp_internal_GLeExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GLeExpr$vtable	_jc_soot_grimp_internal_GLeExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GLeExpr$vtype	_jc_soot_grimp_internal_GLeExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GLeExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_grimp_internal_GLeExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GLeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *);
extern jint _jc_soot_grimp_internal_GLeExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GLeExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GLeExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_grimp_internal_GLeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GLeExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GLeExpr$method_info$getSymbol$ce407d9fb7da8b41;

// Virtual methods structure
struct _jc_soot_grimp_internal_GLeExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *);
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *);
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GLeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntBinopExpr$vmethods	soot_jimple_internal_AbstractIntBinopExpr;
	_jc_soot_grimp_internal_AbstractGrimpIntBinopExpr$vmethods	soot_grimp_internal_AbstractGrimpIntBinopExpr;
	_jc_soot_grimp_internal_GLeExpr$vmethods	soot_grimp_internal_GLeExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GLeExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GLeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GLeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GLeExpr$refs {
    _jc_soot_grimp_internal_GLeExpr$sub_refs	soot_grimp_internal_GLeExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntBinopExpr$sub_refs	soot_grimp_internal_AbstractGrimpIntBinopExpr;
    _jc_soot_jimple_internal_AbstractIntBinopExpr$sub_refs	soot_jimple_internal_AbstractIntBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GLeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GLeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntBinopExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntBinopExpr$sub_nonrefs	soot_grimp_internal_AbstractGrimpIntBinopExpr;
    _jc_soot_grimp_internal_GLeExpr$sub_nonrefs	soot_grimp_internal_GLeExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GLeExpr$object {
	_jc_soot_grimp_internal_GLeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GLeExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GLeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GLeExpr$vtype _jc_soot_grimp_internal_GLeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GLeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GLeExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GLeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GLeExpr.h <==
// public class soot.grimp.internal.GLeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cf732f32c840ec26 soot_grimp_internal_AbstractGrimpIntBinopExpr
// @dep_class 864d3a598d926ee0 soot_grimp_internal_GLeExpr
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class f9eab9f2510f54c9 soot_jimple_internal_AbstractIntBinopExpr

// header file dependencies
// @dep_header soot_grimp_internal_AbstractGrimpIntBinopExpr

#include "soot/grimp/internal/AbstractGrimpIntBinopExpr.h"

#ifndef _JC_soot_grimp_internal_GLeExpr_H_
#define _JC_soot_grimp_internal_GLeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GLeExpr$sub_refs	_jc_soot_grimp_internal_GLeExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GLeExpr$sub_nonrefs	_jc_soot_grimp_internal_GLeExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GLeExpr$refs	_jc_soot_grimp_internal_GLeExpr$refs;
typedef struct _jc_soot_grimp_internal_GLeExpr$nonrefs	_jc_soot_grimp_internal_GLeExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GLeExpr$object	_jc_soot_grimp_internal_GLeExpr$object;

typedef const struct _jc_soot_grimp_internal_GLeExpr$vmethods	_jc_soot_grimp_internal_GLeExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GLeExpr$vtable	_jc_soot_grimp_internal_GLeExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GLeExpr$vtype	_jc_soot_grimp_internal_GLeExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GLeExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_grimp_internal_GLeExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GLeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_grimp_internal_GLeExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GLeExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GLeExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_grimp_internal_GLeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GLeExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GLeExpr$method_info$getSymbol$ce407d9fb7da8b41;

// Virtual methods structure
struct _jc_soot_grimp_internal_GLeExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *) _JC_JCNI_ATTR;
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_grimp_internal_GLeExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GLeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntBinopExpr$vmethods	soot_jimple_internal_AbstractIntBinopExpr;
	_jc_soot_grimp_internal_AbstractGrimpIntBinopExpr$vmethods	soot_grimp_internal_AbstractGrimpIntBinopExpr;
	_jc_soot_grimp_internal_GLeExpr$vmethods	soot_grimp_internal_GLeExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GLeExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GLeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GLeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GLeExpr$refs {
    _jc_soot_grimp_internal_GLeExpr$sub_refs	soot_grimp_internal_GLeExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntBinopExpr$sub_refs	soot_grimp_internal_AbstractGrimpIntBinopExpr;
    _jc_soot_jimple_internal_AbstractIntBinopExpr$sub_refs	soot_jimple_internal_AbstractIntBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GLeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GLeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntBinopExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntBinopExpr$sub_nonrefs	soot_grimp_internal_AbstractGrimpIntBinopExpr;
    _jc_soot_grimp_internal_GLeExpr$sub_nonrefs	soot_grimp_internal_GLeExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GLeExpr$object {
	_jc_soot_grimp_internal_GLeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GLeExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GLeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GLeExpr$vtype _jc_soot_grimp_internal_GLeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GLeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GLeExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GLeExpr_H_ */
